================================
Applied Guides
================================

Full guides through applied examples

The following tutorials can be found
in `zfit tutorials as Jupyter Notebooks. <https://github.com/zfit/zfit-tutorials>`_


..  youtube:: nGzyXVXfHnw
       :width: 320


.. toctree::
    :maxdepth: 1

    ../../../_tmp/zfit-tutorials/guides/constraints_simultaneous_fit_discovery_splot.ipynb

..  youtube:: wdzPvoSDq6o
        :width: 320

.. toctree::
    :maxdepth: 1

    ../../../_tmp/zfit-tutorials/guides/custom_models.ipynb
